@@ -7,12 +7,20 @@ get_base_uri = lambda: Path(getcwd()).absolute().as_uri()
 
 def resolve(dictionary):
 	keys = list(dictionary.keys())
+	new_dict = {}
 	for key in keys:
 		if type(dictionary[key]) == JsonRef:
-			dictionary[key] = dictionary[key].__subject__
+			new_dict[key] = dictionary[key].__subject__
+			continue
+
 		if type(dictionary[key]) == dict:
-			dictionary[key] = resolve(dictionary[key])
-	return dictionary
+			new_dict[key] = resolve(dictionary[key])
+			continue
+
+		else:
+			new_dict[key] = dictionary[key]
+
+	return new_dict
 
 def f(path, base_uri=None):
 	base_uri = (
