@@ -1,5 +1,5 @@
 from genericpath import exists
-from src.mufid.do_nothing import f as do_nothing
+from mufid.do_nothing import f as do_nothing
 from os.path import exists
 from os import mkdir
 
